@@ -3,6 +3,7 @@ import load from './loader'; // Required for loading files dynamically
 import 'bootstrap/js/dist/util'; // All Bootstrap JS requires Util
 import 'bootstrap/js/dist/collapse'; // Used for nav collapse functionality
 import 'bootstrap/js/dist/tab'; // Used for nav collapse functionality
+import 'bootstrap/js/dist/modal'; // Used for nav collapse functionality
 
 import common from './common';
 /*
@@ -17,6 +18,13 @@ const route = className => {
         case 'single_post':
             load('./post');
             break;
+        case 'blog':
+            load('./news');
+            break;
+        case 'template_contact':
+            load('./contact');
+            break;
+
 
     }
 };
